@@ -197,11 +197,22 @@ class Parser:
         for self.line in lines.split('\n'):      #  TODO  deal with pesky \r
             self.line_number += 1
             
+            if self.anneal_last_broken_line():
+                return self.steps
+            
             if not self._parse_line() and \
                     0 < len(self.steps):
                 self._append_to_previous_node()
         
         return self.steps
+    
+    def anneal_last_broken_line(self):
+        if self.steps == []:  return False
+        last = self.steps[-1]
+
+        if len(last.predicate) and re.match(r'\\\s*$', last.predicate[-1]):
+                last.predicate += '\n' + self.line
+                return True
         
     def _parse_line(self):
         self.line = self.line.rstrip()
